==> 0.0.2+4.tar.gz: lib/core/data/service/constaints.dart <==
class ApiConstant {
  static const apiVerion = "v2/";
  static const urlConnectLivekit = "wss://abc.acecom.vn";
  static const urlProduct = "http://dev.panel.hainong.vn/api/";
  static const urlUploadProduct = "http://dev.panel.hainong.vn/";

  static const signIn = apiVerion + "account/login";
  static const signOut = apiVerion + "account/logout";
  static const profile = apiVerion + "account/profile";
  static const call = apiVerion + "calls";
  static const call_join = apiVerion + "calls/join_calls";
  static const chat = apiVerion + "calls/join_chats";
  static const call_update_status = apiVerion + "calls/update_status";
  static const experts = apiVerion + "experts";
  static const devices = apiVerion + "devices";
  static const specializes = "expert/" + apiVerion + "/account/specializes";

  static const postChatMessages = apiVerion + "chat_messages";
  static const getSenderChatMessages =
      apiVerion + "chat_messages/received_messages";

  static const serverToken =
      "AAAA19l1u44:APA91bFvIAl5YyuKIya5LDI2xPdkiFJKK7AwqTkPVRgqgr-AyYO6xoyjz4s-llRIk-fNc9ggZgLAIF1kFF1l3Etdd2l1XwXZgkCDaiA0X9x-5A9FFjrC3j65Swl_Y7kQaTC0WRCpxw3-";
}

class Constaints {
  static const CACHE_TOKEN_LIVE_KIT = "CACHE_TOKEN_LIVE_KIT";
  static const HEADER_CACHE = "HEADER_CACHE";
  static const AUTH_TOKEN_CACHE = "AUTH_TOKEN_CACHE";
  static const USER_CACHE = "USER_CACHE";
  static const NUMBER_BADGE_CACHE = "NUMBER_BADGE_CACHE";
  static const FONT_NAME_CACHE = "FONT_NAME_CACHE";
  static const PRIMARY_COLOR_CACHE = "PRIMARY_COLOR_CACHE";
  static const DOMAIN_URI_CACHE = "DOMAIN_URI_CACHE";
}

==> 0.0.3+3.tar.gz: lib/core/data/service/constaints.dart <==
class ApiConstant {
  static const apiVerion = "/api/v2/";
  static const urlConnectLivekit = "wss://abc.acecom.vn";
  // static const urlProduct = "http://dev.panel.hainong.vn/api/";
  static const urlUploadProduct = "http://dev.panel.hainong.vn/";

  static const signIn = apiVerion + "account/login";
  static const signOut = apiVerion + "account/logout";
  static const profile = apiVerion + "account/profile";
  static const call = apiVerion + "calls";
  static const call_join = apiVerion + "calls/join_calls";
  static const chat = apiVerion + "calls/join_chats";
  static const call_update_status = apiVerion + "calls/update_status";
  static const experts = apiVerion + "experts";
  static const devices = apiVerion + "devices";
  static const specializes = "/api/expert/v2" + "/account/specializes";

  static const postChatMessages = apiVerion + "chat_messages";
  static const getSenderChatMessages =
      apiVerion + "chat_messages/received_messages";

  static const serverToken =
      "AAAA19l1u44:APA91bFvIAl5YyuKIya5LDI2xPdkiFJKK7AwqTkPVRgqgr-AyYO6xoyjz4s-llRIk-fNc9ggZgLAIF1kFF1l3Etdd2l1XwXZgkCDaiA0X9x-5A9FFjrC3j65Swl_Y7kQaTC0WRCpxw3-";
}

class Constaints {
  static const CACHE_TOKEN_LIVE_KIT = "CACHE_TOKEN_LIVE_KIT";
  static const HEADER_CACHE = "HEADER_CACHE";
  static const AUTH_TOKEN_CACHE = "AUTH_TOKEN_CACHE";
  static const USER_CACHE = "USER_CACHE";
  static const NUMBER_BADGE_CACHE = "NUMBER_BADGE_CACHE";
  static const FONT_NAME_CACHE = "FONT_NAME_CACHE";
  static const PRIMARY_COLOR_CACHE = "PRIMARY_COLOR_CACHE";
  static const DOMAIN_URI_CACHE = "DOMAIN_URI_CACHE";
}
